@@ -257,9 +257,11 @@ class dgutIllness(dgutUser):
             'username',
             'whitelist',
             'importantAreaMsg',
+            'acid_test_results',
+            'two_week_itinerary',
         ]
         for key in pop_list:
-            if data.get(key):
+            if key in data:
                 data.pop(key)
 
         # 获取GPS位置
@@ -275,6 +277,14 @@ class dgutIllness(dgutUser):
 
 
 class dgutJwxt(dgutUser):
+    '''
+    莞工教务系统类
+
+    username : 中央认证账号用户名
+
+    password : 中央认证账号密码
+    '''
+
     def __init__(self, username: str, password: str):
         dgutUser.__init__(self, username, password)
         self.session.headers = {
